##############################################################################
# Module : rssscanfreqdlg.py
# Author : Old King Cole
# Date   : 15 October 2005
#
# Description : Dialog for tweaking RSS scanning frequency
#
##############################################################################
import wx


class RSSScanFreqDialog(wx.Dialog):
    def __init__(self, parent, ID, title,
                 pos = wx.DefaultPosition, size = wx.DefaultSize,
                 style = wx.DEFAULT_DIALOG_STYLE):
        pre = wx.PreDialog()
        pre.Create(parent, ID, title, pos, size, style)
        self.this = pre.this
        self.parent = parent
        self.utility = self.parent.utility
        self.localize = self.utility.lang.get

        p = wx.Panel(self, -1)
        outerbox = wx.BoxSizer(wx.VERTICAL)

        rssscanfreqsection = wx.StaticBoxSizer(wx.StaticBox(p, -1, ''), wx.VERTICAL)

        rssscanfreqbox = wx.BoxSizer(wx.HORIZONTAL)
        rssscanfreqbox.Add(wx.StaticText(p, -1, self.localize('rssscanfreq')), 0, wx.ALIGN_CENTER_VERTICAL)
        self.rssscanfreq = wx.TextCtrl(p, -1, self.utility.abcparams['rssscanfreq'], wx.Point(-1, -1), wx.Size(40, -1))
        self.rssscanfreq.Bind(wx.EVT_CHAR, self.utility.onWriteDigits)
        rssscanfreqbox.Add(self.rssscanfreq, 0, wx.ALIGN_CENTER_VERTICAL | wx.LEFT | wx.RIGHT, 5)
        rssscanfreqbox.Add(wx.StaticText(p, -1, self.localize('minute_short')), 0, wx.ALIGN_CENTER_VERTICAL)

        rssscanfreqsection.Add(rssscanfreqbox, 0, wx.ALIGN_CENTER_VERTICAL | wx.TOP, 3)

        outerbox.Add(rssscanfreqsection, 0, wx.ALIGN_CENTER_HORIZONTAL | wx.TOP, -4)

        applybtn = wx.Button(p, -1, self.localize('apply'), size = (60, -1))
        okbtn = wx.Button(p, -1, self.localize('ok'), size = (60, -1))
        cancelbtn = wx.Button(p, -1, self.localize('cancel'), size = (60, -1))

        buttonbox = wx.BoxSizer(wx.HORIZONTAL)
        buttonbox.Add(applybtn, 0, wx.ALL, 5)
        buttonbox.Add(okbtn, 0, wx.ALL, 5)
        buttonbox.Add(cancelbtn, 0, wx.ALL, 5)

        outerbox.Add(buttonbox, 0, wx.ALIGN_CENTER)

        p.SetAutoLayout(True)
        p.SetSizer(outerbox)
        p.Fit()
        self.SetClientSize(p.GetSize())

        # Add events
        self.Bind(wx.EVT_BUTTON, self.onOK, okbtn)
        self.Bind(wx.EVT_BUTTON, self.onApply, applybtn)
        self.Bind(wx.EVT_BUTTON, self.onCancel, cancelbtn)
        self.Bind(wx.EVT_CLOSE, self.onCancel)

        if self.utility.abcparams['rssscanfreqdlgx'] != '-1':
            self.MoveXY(int(self.utility.abcparams['rssscanfreqdlgx']), int(self.utility.abcparams['rssscanfreqdlgy']))

    def onCancel(self, event = None):
        self.EndModal(wx.ID_CANCEL)

    def onApply(self, event):
        errortype = False
        try:
            scanfreq = int(self.rssscanfreq.GetValue())
        except:
            errortype = True
        if errortype or scanfreq < 5:
            dlg = wx.MessageDialog(self, self.localize('rssscanfreqwarning'), self.localize('abcokcerror'), wx.ICON_ERROR)
            dlg.ShowModal()
            dlg.Destroy()
            return False
        self.utility.abcparams['rssscanfreq'] = self.rssscanfreq.GetValue()
        self.parent.parent.resetGlobalTimer()
        return True

    def onOK(self, event):
        if self.onApply(event):
            self.EndModal(wx.ID_OK)
